echo
echo
echo "*************************************************"
echo "****                                         ****"
echo "**** Création d'une base de données JSQlQUIZ ****"
echo "**** 1.0                                     ****"
echo "**** J.-F. Condotta (jsqlquiz.fr)            ****"
echo "****                                         ****"
echo "*************************************************"
echo
echo
if [ "$#" -ne 1 ]; then
 echo "Le nombre d'arguments est invalide !"
 echo "Vous devez passer en argument le nom du sous-dossier de la base de données à traiter se trouvant dans descriptionDatabases !"
fi
database=$1
echo "Base de données à traiter : $database"


if [[ ! $database =~ .*\/.* ]];then
	echo "L'argument doit contenir \/ !!!"
	exit 1
fi

nomDatabase=`expr $database : '.*\/\([A-Z]*\)_DB'`
echo "Nom de la base de données : $nomDatabase"

if [ ${#nomDatabase} -lt 1 ];then
echo "Le nom de la base de données n'est pas correct (vérifier que le nom de la base de données est suivi par _DB) !"
exit 1
fi

repSource="./descriptionDatabases/$database"
repDest="./finalDatabases/$database"

if [ ! -d "$repSource" ];then
echo "Le dossier d'entrée contenant la description de la base de données n'existe pas !"
exit 1
fi
if [ -d "$repDest" ];then
rm -r "$repDest"
fi
mkdir -p "$repDest"

echo
echo "*************************************************"
echo "****                                         ****"
echo "**** Traitement du fichier descriptionDB.xml ****"
echo "****                                         ****"
echo "*************************************************"
echo

#################### Création du fichier HTML correspondant à la description de la base de données
echo "**** Création de descriptionDB.html ****"
java -jar "./bin/TransformXSLT.jar" "./data/xslt/descriptionDB.xsl" "$repSource/descriptionDB.xml" "$repDest/descriptionDB.html"
cp "./data/css/descriptionDB.css" "$repDest/descriptionDB.css"
#################### Création du fichier HTML correspondant au schéma de la base de données
echo "**** Création de schemeDB.html ****"
mkdir -p "./temp"
java -jar "./bin/TransformXSLT.jar" "./data/xslt/schemeDB.xsl" "$repSource/descriptionDB.xml" "$repDest/schemeDB.html"
cp "$repDest/schemeDB.html" "./temp/schemeDB.html"
#################### Création du fichier HTML correspondant au terminal SQL de la base de données
echo "**** Création de terminalDB.html ****"
java -jar "./bin/TransformXSLT.jar" "./data/xslt/terminalDB.xsl" "$repSource/descriptionDB.xml" "$repDest/terminalDB.html"
cp "./data/css/terminalDB.css" "$repDest/terminalDB.css"
#################### Création du fichier indosDB.xml
echo "**** Création de infosDB.html ****"
java -jar "./bin/TransformXSLT.jar" "./data/xslt/infosDB.xsl" "$repSource/descriptionDB.xml" "$repDest/infosDB.xml"

echo
echo "********************************************************"
echo "****                                                ****"
echo "**** Traitement des fichiers creationContentDB.sql  ****"
echo "**** et creationContentDB.sql                       ****"
echo "****                                                ****"
echo "********************************************************"
echo
#################### Création du fichier HTML correspondant au contenu des tables de la base de données
echo "**** Création de contentDB.html ****"
java -jar "./bin/DBContentAnalyser.jar" "$repSource/creationDB.sql" "$repSource/creationContentDB.sql" "$repDest/contentTablesDB.html" "contentTablesDB.css" "$nomDatabase"
cp "./data/css/contentTablesDB.css" "$repDest/contentTablesDB.css"
cp "$repSource/creationDB.sql" "$repDest"
cp "$repSource/creationContentDB.sql" "$repDest"

echo
echo "****************************************"
echo "****                                ****"
echo "**** Finalisation de la création    ****"
echo "****                                ****"
echo "****************************************"
echo
##################### Archivage
rm -r ./temp
rm derby.log
cd ./finalDatabases
#nomArchive=${database/\//-}
nomArchive=$(echo $database | sed "s/\//-/g")
echo $nomArchive
if [ -f "$nomArchive.dbz" ];then
rm "$nomArchive.dbz"
fi
zip -r $nomArchive.dbz $database
mkdir -p "../databases"
cp $nomArchive.dbz ../databases
cd ..
rm -r ./finalDatabases

echo
echo "*******************"
echo "****           ****"
echo "**** Ciao !    ****"
echo "****           ****"
echo "*******************"
echo


